==> fcitx_3.4.3.orig.tar.gz: fcitx-3.4.3.orig/src/PYFA.h <==
/***************************************************************************
 *   Copyright (C) 2002~2005 by Yuking                                     *
 *   yuking_net@sohu.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _PYFA_H
#define _PYFA_H

#include "main.h"

typedef struct MH_PY {
    char           *strMap;
    int             bMode;
} MHPY;

typedef struct {
    char            strPY[7];
    int            *pMH;
} PYTABLE;

int             GetMHIndex_C (char map);
int             GetMHIndex_S (char map);

#endif

==> fcitx_3.6.2.orig.tar.gz: fcitx-3.6.2/src/PYFA.h <==
/***************************************************************************
 *   Copyright (C) 2002~2005 by Yuking                                     *
 *   yuking_net@sohu.com                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _PYFA_H
#define _PYFA_H

#include "main.h"

typedef struct MH_PY {
    char           *strMap;
    int             bMode;
} MHPY;

typedef struct {
    char            strPY[7];
    int            *pMH;
} PYTABLE;

int             GetMHIndex_C (char map);
//ʱ磬û롰jiu'sʱӦÿԳ֡ǡʣǷģƴ
int             GetMHIndex_S (char map, Bool bMode);
Bool		IsZ_C_S (char map);

#endif
